using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

using com.ibm.gre;

namespace SampleApp
{
	/// <summary>
	/// The ResultListForm is used to Display the results of
	/// executing a Records Manager Query.
	/// This form demonstrates the use of the IRMResultList class. 
	/// </summary>
	public class ResultListForm : System.Windows.Forms.Form
	{
		public ResultListForm(ClientSession session, Control parent, IRMResultList resultList, int nFlPlnViewID)
		{
			//
			// Required for Windows Form Designer support
			//
			InitializeComponent();

			util = new Util(this,parent);
			m_parent = parent;
			m_session = session;
			m_IRMResultList = resultList;
			m_nFlPlnViewID = nFlPlnViewID;
		}

		/// <summary>
		/// Clean up any resources being used.
		/// </summary>
		protected override void Dispose( bool disposing )
		{
			if( disposing )
			{
				if(components != null)
				{
					components.Dispose();
				}
			}
			base.Dispose( disposing );
		}

		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.lvComponents = new System.Windows.Forms.ListView();
			this.contextMenu1 = new System.Windows.Forms.ContextMenu();
			this.mnuViewResultListItem = new System.Windows.Forms.MenuItem();
			this.mnuEdiResultListItem = new System.Windows.Forms.MenuItem();
			this.mnuDeleteResultListItem = new System.Windows.Forms.MenuItem();
			this.menuItem1 = new System.Windows.Forms.MenuItem();
			this.mnuTargesOftResultListItem = new System.Windows.Forms.MenuItem();
			this.SuspendLayout();
			// 
			// lvComponents
			// 
			this.lvComponents.ContextMenu = this.contextMenu1;
			this.lvComponents.Dock = System.Windows.Forms.DockStyle.Fill;
			this.lvComponents.FullRowSelect = true;
			this.lvComponents.Location = new System.Drawing.Point(0, 0);
			this.lvComponents.Name = "lvComponents";
			this.lvComponents.Size = new System.Drawing.Size(688, 445);
			this.lvComponents.TabIndex = 0;
			this.lvComponents.View = System.Windows.Forms.View.Details;
			// 
			// contextMenu1
			// 
			this.contextMenu1.MenuItems.AddRange(new System.Windows.Forms.MenuItem[] {
																						 this.mnuViewResultListItem,
																						 this.mnuEdiResultListItem,
																						 this.mnuDeleteResultListItem,
																						 this.menuItem1,
																						 this.mnuTargesOftResultListItem});
			// 
			// mnuViewResultListItem
			// 
			this.mnuViewResultListItem.Index = 0;
			this.mnuViewResultListItem.Text = "View";
			this.mnuViewResultListItem.Click += new System.EventHandler(this.mnuViewResultListItem_Click);
			// 
			// mnuEdiResultListItem
			// 
			this.mnuEdiResultListItem.Index = 1;
			this.mnuEdiResultListItem.Text = "Edit";
			this.mnuEdiResultListItem.Click += new System.EventHandler(this.mnuEdiResultListItem_Click);
			// 
			// mnuDeleteResultListItem
			// 
			this.mnuDeleteResultListItem.Index = 2;
			this.mnuDeleteResultListItem.Text = "Delete";
			this.mnuDeleteResultListItem.Click += new System.EventHandler(this.mnuDeleteResultListItem_Click);
			// 
			// menuItem1
			// 
			this.menuItem1.Index = 3;
			this.menuItem1.Text = "-";
			// 
			// mnuTargesOftResultListItem
			// 
			this.mnuTargesOftResultListItem.Index = 4;
			this.mnuTargesOftResultListItem.Text = "Find in File Plan";
			this.mnuTargesOftResultListItem.Click += new System.EventHandler(this.mnuTargesOftResultListItem_Click);
			// 
			// ResultListForm
			// 
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(688, 445);
			this.Controls.Add(this.lvComponents);
			this.Name = "ResultListForm";
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "ResultListForm";
			this.Load += new System.EventHandler(this.ResultListForm_Load);
			this.ResumeLayout(false);

		}
		#endregion

		#region events
		private void ResultListForm_Load(object sender, System.EventArgs e)
		{
			CommonTasks.DisplayResultList(lvComponents,m_IRMResultList,m_nFlPlnViewID);
		}

		private void mnuDeleteResultListItem_Click(object sender, System.EventArgs e)
		{
			CommonTasks.DeleteListItems(this,m_session,util,lvComponents);
		}

		private void mnuViewResultListItem_Click(object sender, System.EventArgs e)
		{
			int count = lvComponents.SelectedItems.Count;
			if(count > 0)
			{
				IEnumerator items = lvComponents.SelectedItems.GetEnumerator();
				items.MoveNext();
				ListViewItem lvi = (ListViewItem)items.Current;
				IRMComponent irm = (IRMComponent)lvi.Tag;
				CommonTasks.viewSeletedItem(m_parent,m_session,irm);
			}
		}

		private void mnuEdiResultListItem_Click(object sender, System.EventArgs e)
		{
			int count = lvComponents.SelectedItems.Count;
			if(count > 0)
			{
				IEnumerator items = lvComponents.SelectedItems.GetEnumerator();
				items.MoveNext();
				ListViewItem lvi = (ListViewItem)items.Current;
				IRMComponent irm = (IRMComponent)lvi.Tag;
				if(irm.FlPlnCmpntDefID > 0 || irm.FlPlnCmpntDefID == (int)IRMConstants.ComponentDefinitionTypes.FILE_PLAN_VIEW)
				{
					string xml = m_session.getTemplateController().getFilePlanComponent(irm.FlPlnCmpntID,0,(int)IRMConstants.TemplateOptions.EXPAND_LISTS_AND_PROFILE_FIELDS);

					IRMFields fields = new IRMFields(xml);
					fields.hideSecurityFields(); //This is a convenience method to hide security fields if they are not being used
					fields.inactivateSecurityFields(); //This is a convenience method to make sure security fields are not added
						
					//Hide some fields we never want to display
					fields.setVisabilityByFlPlnCmpntAttrDefColNm("FlPlnCmpntID",false);
					fields.setVisabilityByFlPlnCmpntAttrDefColNm("LastAddtnDt",false);
					fields.setVisabilityByFlPlnCmpntAttrDefColNm("LastRtrvDt",false);
						
					//Inactivate fields we do not want to be set in the Fields Collection
					fields.setActiveStateByFlPlnCmpntAttrDefColNm("FlPlnCmpntID",false);
					fields.setActiveStateByFlPlnCmpntAttrDefColNm("LastAddtnDt",false);
					fields.setActiveStateByFlPlnCmpntAttrDefColNm("LastRtrvDt",false);
						
					ComponentForm cmpntFrm = new ComponentForm(m_session, irm ,m_parent,fields,ComponentForm.EDIT);
					if(cmpntFrm.ShowDialog(this) == DialogResult.OK)
					{
						//TODO could go through the long and complicated proccess
						//of updating changed columns
					}
				}
			}

		}

		private void mnuTargesOftResultListItem_Click(object sender, System.EventArgs e)
		{
			int count = lvComponents.SelectedItems.Count;
			if(count > 0)
			{
				IEnumerator items = lvComponents.SelectedItems.GetEnumerator();
				items.MoveNext();
				ListViewItem lvi = (ListViewItem)items.Current;
				IRMComponent irm = (IRMComponent)lvi.Tag;

				Form1 frm = (Form1)m_parent;
				frm.Select();
				frm.FindTreeNode(irm.FlPlnCmpntID,irm.FlPlnViewID,irm.FlPlnCmpntDefID);
			}
		}
		#endregion

		#region MemberVariables
		private Util util;
		private Control m_parent;

		private ClientSession m_session;
		private IRMResultList m_IRMResultList;
		private int m_nFlPlnViewID;

		private System.Windows.Forms.ListView lvComponents;
		private System.Windows.Forms.ContextMenu contextMenu1;
		private System.Windows.Forms.MenuItem mnuViewResultListItem;
		private System.Windows.Forms.MenuItem mnuEdiResultListItem;
		private System.Windows.Forms.MenuItem mnuDeleteResultListItem;
		private System.Windows.Forms.MenuItem menuItem1;
		private System.Windows.Forms.MenuItem mnuTargesOftResultListItem;
		/// <summary>
		/// Required designer variable.
		/// </summary>
		private System.ComponentModel.Container components = null;
		#endregion
	}
}
