/*
 * Created on Jan 26, 2005
 */
package com.ibm.gre.samples.collectionhelpers;

/**
 * The OptionalFields class represents
 * bit mask values specifying
 * fields that can optionaly be added and
 * displayed for a Life Cycle Query.
 * These elements can be found as members of the "GetEligibleFilePlanComponents"
 * element part of the input to the GET_ELIGIBLE_FILE_PLAN_COMPONENTS
 * BatchController task.
 */
public class OptionalFields {

	/**
	 * Indicates No Optional Fields
	 */
	public static int NO_FIELDS = 0;
	/**
	 *  Indicates the Reference Date To should be displayed for input. 
	 */
	public static int REFERENCE_DATE_TO = 1;
	/**
	 *  Indicates the Reference Date From should be displayed for input.
	 */
	public static int REFERENCE_DATE_FROM = 2;
	/**
	 *  Indicates the Disposal Authority field should be displayed for input.
	 */
	public static int DISPOSAL_AUTHORITY = 4;
	/**
	 *  Indicates the Eligible for Cutt Off checkbox should be displayed for input.
	 */
	public static int ELIGIBLE_FOR_CUT_OFF = 8;
	/**
	 *  Indicates the Eligible for close checkbox should be displayed for input.
	 */
	public static int ELIGIBLE_FOR_CLOSE = 16;
	/**
	 *  Indicates the Eligible for Transition checkbox should be displayed for input.
	 */
	public static int ELIGIBLE_FOR_TRANSITION = 32;
	/**
	 *  Indicates the Phase list should be displayed for input.
	 */
	public static int PHASE_ID = 64;
	public static int LIFE_CYCLE_QUERY_TYPE = 128;

	/**
	 *  Constructor
	 * @param mask The bit mask containing the optional fields to display.
	 */
	public OptionalFields(int mask)
	{
		m_mask = mask;
	}

	/**
	 *  Returns true if the Reference Date From field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editReferenceDateFrom()
	{
		return ((m_mask & REFERENCE_DATE_FROM) == REFERENCE_DATE_FROM);
	}
	/**
	 *  Returns true if the Reference Date To field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editReferenceDateTo()
	{
		return ((m_mask & REFERENCE_DATE_TO) == REFERENCE_DATE_TO);	
	}
	/**
	 *  Returns true if the Disposal Authority field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editDisposalAuthority()
	{
		return ((m_mask & DISPOSAL_AUTHORITY) == DISPOSAL_AUTHORITY);	
	}
	/**
	 *  Returns true if the Eligible For Cutoff field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editEligibleForCutOff()
	{
		return ((m_mask & ELIGIBLE_FOR_CUT_OFF) == ELIGIBLE_FOR_CUT_OFF);	
	}
	/**
	 *  Returns true if the Eligible for Close field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editEligibleForClose()
	{
		return ((m_mask & ELIGIBLE_FOR_CLOSE) == ELIGIBLE_FOR_CLOSE);	
	}
	/**
	 *  Returns true if the Eligible for Transition field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editEligibleForTransition()
	{
		return ((m_mask & ELIGIBLE_FOR_TRANSITION) == ELIGIBLE_FOR_TRANSITION);	
	}
	/**
	 *  Returns true if the Phase ID field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editPhaseId()
	{
		return ((m_mask & PHASE_ID) == PHASE_ID);	
	}
	/**
	 *  Returns true if the Life Cycle Query type field should be displayed for edit.
	 * @return boolean
	 */
	public boolean editLifeCycleQueryType()
	{
		return ((m_mask & LIFE_CYCLE_QUERY_TYPE) == LIFE_CYCLE_QUERY_TYPE);	
	}

	private int m_mask;

}
