/**
 *Licensed Materials - Property of IBM
 *"Restricted Materials of IBM"
 *5746-SM2
 *  Copyright IBM Corp. 1999, 2003 All Rights Reserved.
 *US Government Users Restricted Rights - Use, duplication or
 *disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */


package com.ibm.gre.toolkit.samples;

import java.util.EventObject;
import java.util.HashMap;

import javax.ejb.CreateException;
import javax.naming.NamingException;
import javax.rmi.PortableRemoteObject;

import org.apache.log4j.Logger;

import com.ibm.gre.engine.ejb.facade.FilePlanComponentControllerEJBLocal;
import com.ibm.gre.engine.ejb.facade.FilePlanComponentControllerEJBLocalHome;
import com.ibm.gre.engine.extension.FilePlanComponentListener;
import com.ibm.gre.engine.util.BusinessComponentsJNDINames;
import com.ibm.gre.engine.util.BusinessLayerError;
import com.ibm.gre.engine.util.ExtensionParamKeys;
import com.ibm.gre.engine.util.RecordManagerException;
import com.ibm.gre.engine.util.RecordManagerExceptionTypes;
import com.ibm.gre.engine.util.ServiceLocator;
import com.ibm.gre.engine.value.StateMachine;


/**
 *	This sample shows how to implement an IRM Logic Extension.
 *
 *	It listens to the afterUpdateEvent. It shows how to get parameters, how to obtain IRM Facade stateful
 *	session bean and how to invode IRM API through that session bean.
 *
 */


/*
 * All IRM Logic Extension need to implement com.ibm.gre.engine.extension.FilePlanComponentListener interface. 
 */
public class IRMSampleLogicExtension implements FilePlanComponentListener {
	
	/*
	 * Get extension logger. This logger will write to the file record_manager_extensions.log(under
	 * default directory i.e. /WebSphere/AppServer)
	 */ 
	private static Logger logger = Logger.getLogger("EXTENSION");

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#afterUpdateEvent(EventObject)
	 */
	public void afterUpdateEvent(EventObject e)
		throws RecordManagerException
	{
		logger.info("   ");
		logger.info("starting afterUpdateEvent Listener...");
		
		//Get the parameter map from the EventObject.
		HashMap map = (HashMap) e.getSource();
		
		//Get parameter ExtensionParamKeys.FILE_PLAN_COMPONENT_ID from the parameter map.
		long id = ((Long) map.get(ExtensionParamKeys.FILE_PLAN_COMPONENT_ID)).longValue();
		logger.info("FilePlanComponentId " + id);

		//Get parameter ExtensionParamKeys.FILE_PLAN_COMPONENT_XML from the parameter map.
		String xml = (String) map.get(ExtensionParamKeys.FILE_PLAN_COMPONENT_XML);
		logger.info("FilePlanComponentXML for Update " + xml);
		
		//Get parameter ExtensionParamKeys.STATE_MACHINE from the parameter map.
		StateMachine stateMachine = (StateMachine) map.get(ExtensionParamKeys.STATE_MACHINE);
		
		logger.info("Getting file plan component controller...");
		//Using the stateMachine to obtain the local stateful session bean FilePlanComponentControllerEJBLocal
		try{	
			ServiceLocator locator = ServiceLocator.getInstance();
			Object obj = locator.lookup("local:ejb/" + BusinessComponentsJNDINames.FILE_PLAN_COMPONENT_CONTROLLER_JNDI);
	
			FilePlanComponentControllerEJBLocalHome uch = (FilePlanComponentControllerEJBLocalHome) PortableRemoteObject.narrow(obj, FilePlanComponentControllerEJBLocalHome.class);
			FilePlanComponentControllerEJBLocal ucl = null;
	
			ucl = uch.create(stateMachine);			
			
			//Invoke API FilePlanComponentControllerEJB.getFilePlanComponentField(long filePlanComponentId, String fieldName)
			logger.debug("host id:" + ucl.getFilePlanComponentField(id, "RecHsID"));
		}
		catch(NamingException ex){
			RecordManagerException rme = new RecordManagerException(BusinessLayerError.JNDI_LOOKUP_FAILED, ex.getMessage(), getClass().getName(), RecordManagerExceptionTypes.BUSINESS_LOGIC, ex);
			rme.addMessageParameter(ex.getMessage());
			throw rme;
		}
		catch(CreateException ce){
			logger.debug("Extension exception:", ce);			
			throw new RecordManagerException(BusinessLayerError.UNKNOWN, ce.getMessage(), getClass().getName(), RecordManagerExceptionTypes.SYSTEM, ce);
		}
		
		logger.info("The end of afterUpdateEvent Listener...");
	}
	
	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#beforeAddEvent(java.util.EventObject)
	 */
	public void beforeAddEvent(EventObject e)
		 throws RecordManagerException
	{
	}
	
	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#afterAddEvent(java.util.EventObject)
	 */
	public void afterAddEvent(EventObject e)
		throws RecordManagerException
	{
	}
	
	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#beforeDeleteEvent(java.util.EventObject)
	 */
	public void beforeDeleteEvent(EventObject e)
		throws RecordManagerException
	{
	}
	
	public void afterDeleteEvent(EventObject e)
		throws RecordManagerException
	{
	}		
	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#afterGetByIDEvent(EventObject)
	 */
	public void afterGetByIDEvent(EventObject e)
		throws RecordManagerException
	{
	}


	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#beforeGetByIDEvent(EventObject)
	 */
	public void beforeGetByIDEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#beforeUpdateEvent(EventObject)
	 */
	public void beforeUpdateEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#afterGetByBarCodeEvent(EventObject)
	 */
	public void afterGetByBarCodeEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#beforeGetByBarCodeEvent(EventObject)
	 */
	public void beforeGetByBarCodeEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#afterSetFieldEvent(EventObject)
	 */
	public void afterSetFieldEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#beforeSetFieldEvent(EventObject)
	 */
	public void beforeSetFieldEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#afterGetFieldEvent(EventObject)
	 */
	public void afterGetFieldEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.ejb.business.listener.FilePlanComponentListener#beforeGetFieldEvent(EventObject)
	 */
	public void beforeGetFieldEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#afterTransitionEvent(EventObject)
	 */
	public void afterTransitionEvent(EventObject e)
		throws RecordManagerException
	{
	}

	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#beforeTransitionEvent(EventObject)
	 */
	public void beforeTransitionEvent(EventObject e)
		throws RecordManagerException
	{
	}

	
	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#beforeSupercedeEvent(java.util.EventObject)
	 */
	public void beforeSupercedeEvent(EventObject e) throws RecordManagerException {
		
	}

	
	/**
	 * @see com.ibm.gre.engine.extension.FilePlanComponentListener#afterSupercedeEvent(java.util.EventObject)
	 */
	public void afterSupercedeEvent(EventObject e) throws RecordManagerException {
		
	}

}
